#
# spec file for package topgrade
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           topgrade
Version:        16.0.1
Release:        1.2
Summary:        Upgrade all the things
License:        GPL-3.0-only
Group:          Productivity/Other
URL:            https://github.com/%{name}-rs/%{name}
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  zstd
ExclusiveArch:  %{rust_tier1_arches}

%description
Keeping your system up to date usually involves invoking multiple package managers. This results in big, non-portable shell one-liners saved in your shell.
To remedy this, Topgrade detects which tools you use and runs the appropriate commands to update them

%prep
%autosetup -a1

%build
%{cargo_build}

%install
%{cargo_install}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Fri Oct 25 2024 gerald_chen@foxmail.com
- Update to version 16.0.1:
  * chore: release v16.0.1 (#940)
  * fix: pypi-release-action: downgrade upload-artifact and download-artifact to v3 (#938)
  * fix: tmux unknown cmd: attach-client (#937)
  * i18n(app.yml): new language zh_TW (#931)
  * Fix typo in exit_status (#934)
  * revert: PR 866 (#927)
  * chore: release v16.0.0 (#925)
  * ci: correct checker binary name (#926)
  * fix: use single quotes for locale keys with new line char (#920)
  * Add i18n by using rust i18n (#807)
  * docs: --only is no longer experimental (#919)
  * feat(brew): Add `greedy-auto-updates` option to Brew (#914)
  * docs: don't call execute("bin_name_str") (#916)
  * Add Pixi to topgrade (#915)
  * feat(brew): use sudo if Homebrew owned by another user on Linux (#904)
  * feat: tmux session attach mode (#901)
  * Remove check for whether conda config contains auto_activate_base (#905)
  * feat: clean scoop cache if cleanup is enabled (#909)
  * fix: aura since v4.0.6 does not need sudo (#908)
  * chore: pin toolchain to MSRV(1.76) (#900)
  * Add Debian-based system builds (#898)
  * fix: a panic introduced by improper unwrap() (#899)
  * Containers step: new runtime option to configuration (#896)
  * feat: support step Bun on Windows (#893)
  * Adds `uv` step (#890)
  * Add aqua tool installer cli (#889)
  * chore: update winget-releaser to use main branch (#888)
  * Fix `RubyGems` issues for `mise` regarding `sudo` (#887)
  * Update README.md (#882)
  * feat: add volta packages (#883)
  * Allow Nix unfree packages to be upgraded (#881)
  * chore: improve Windows Update step and add PSWindowsUpdate Module (#842)
  * ci: fix release_to_aur.yml (#879)
  * Update SECURITY.md (#878)
  * refactor: fix Windows clippy (#880)
  * Fix nix upgrades (#874)
  * feat: support ZVM (#777)
  * Fix nightly clippy warnings (#872)
  * feat(os): support NI Linux Real-Time's opkg package manager (#870)
  * feat(linux.rs): Add support for Funtoo (#868)
  * feat: don't run reboot with sudo on Linux with systemd (#866)
  * Fix `pyenv: no such command 'update'`  (#860)
  * chore(deps): bump zerovec-derive from 0.10.2 to 0.10.3 (#858)
  * chore(deps): bump zerovec from 0.10.2 to 0.10.4 (#856)
  * docs: document that maintenance continues (#855)
  * docs: document that it is currently unmaintained
  * fix: traverse symbolic links under `$CONIG_DIR/topgrade.d` (#852) (#853)
  * feat: support Poetry (#790)
  * Small clap adjustments (#846)
  * docs: update release procedure (#845)
* Thu Jul  4 2024 gerald_chen@foxmail.com
- Update to version 15.0.0:
  * chore: prepare for v15.0.0 (#843)
  * feat: new step Lensfun's database update (#839)
  * fix: consider TMUX_PLUGIN_MANAGER_PATH when searching tpm binary (#835)
  * chore: collect `--dry-run` and `--yes` opts info in feature request template (#838)
  * chore(deps): bump curve25519-dalek from 4.1.2 to 4.1.3 (#827)
  * style: allow unused ExecutorChild (#829)
  * chore: bump deps (#823)
  * Run MasonUpdate as part of the vim updates (#821)
  * fix(RubyGems): support no-sudo updating for rbenv and rvm (#820)
  * deps: bump libc from 0.2.153 to 0.2.155 (#818)
  * Add linux mint support (#817)
  * chore: build binary for both macOS aarch64 and amd64 (#816)
  * ci: replace deprecated gh actions with alternatives (#814)
  * chore: update PR template (#815)
  * ci: remove code coverage test & uniform file names (#811)
  * add upgrade stuff for bedrock linuxmint strata (#813)
  * feat: add support for chimera linux (#808)
  * chore(deps): bump mio from 0.8.10 to 0.8.11 (#729)
  * chore(deps): bump h2 from 0.3.24 to 0.3.26 (#766)
  * chore(deps): bump rustls from 0.21.10 to 0.21.12 (#804)
  * Dependatbot Updates (#802)
  * feat: support auto-cpufreq (#800)
  * Add rye support (#799)
  * fix: Fedora Sway Atomic should be recognized as FedoraImmutable (#795)
  * refactor: 2 clippy warnings (#789)
  * Always display windows update step (#781)
  * fix(os): detect Fedora IoT Edition as immutable Fedora variant (#774)
  * Add config flag to toggle verbose Git repository output. (#763)
  * fix: better `dotnet tool list` header parsing (#772)
  * Fix local host detection for remotes with user  (#755)
  * feat: support update PlatformIO Core (#759)
  * feat: add support for mise (#757)
  * FIXES #708: add config directive for pkg_* cleanup on OpenBSD (#753)
  * fix: don't use Command::new(bin_name) as it won't work on Windows (#750)
  * style: fix 2 clippy lint unless_vec & unused_io_amount (#751)
  * feat: support update ClamAV databases (#747)
  * feat: put step logs in a span (#746)
  * Add support for Lean 4's elan (#742)
  * refactor: make GitSteps a dedicated step (#737)
  * fix: use env BUN_INSTALL to locate package.json (#734)
  * fix(pipx): adds `--include-injected` argument to `pipx` (#726)
  * feat: adds `xcodes` step (#643)
  * Adds `pyenv` step (#724)
  * Update GitHub Actions workflow for Codecov integration (#718)
  * Add GitHub Actions Workflow for Build and Test (#717)
  * Create devskim.yml to enable GitHub code scanning for this repository (#700)
  * chore: git ignore more (#715)
  * chore: bump deps (#714)
  * revert: revert 614 to remove the -p option (#713)
  * feat: also detect Helix step with bin name hx (#710)
  * fix: fetch and build Helix grammar as a regular user (#698)
  * Add .vs to .gitignore (#706)
  * chore(deps): bump actions/download-artifact from 3 to 4 (#704)
  * chore(deps): bump EnricoMi/publish-unit-test-result-action from 1 to 2 (#705)
  * Fix OpenBSD Step failing to build with `E0599` (#707)
  * fix: zinit default install location (#625)
  * docs: document brew config entries[skip ci] (#696)
  * feat(brew): adds "greedy-latest" option to Brew (#636)
  * feat: support waydroid (#687)
  * chore(deps): bump actions/checkout from 2 to 4 (#688)
  * chore(deps): bump actions/upload-artifact from 3 to 4 (#689)
  * chore(deps): bump actions/cache from 1 to 4 (#690)
  * chore(deps): bump codecov/codecov-action from 1 to 4 (#691)
  * chore(deps): bump katyo/publish-crates from 1 to 2 (#692)
  * docs: update install doc with Winget (#693)
  * Keeping actions up to date with Dependabot (#685)
  * Publish new releases of topgrade to the Windows Package Manager with WinGet Releaser
  * ci: add macOS aarch64 check (#680)
  * feat: add `fetch_head` configuration option into `brew` (#679)
  * Fix/winget (#670)
  * fix: correct typos in output (#677)
  * docs: fix a wrong preposition[skip ci] (#676)
  * ci: run cargo test in ci (#674)
  * feat: Add support for Wolfi (#672)
  * Fix/usoclient (#669)
  * Fix/pswindowsupdate (#671)
  * Update Cargo.lock (#673)
  * feat: certbot renew (#665)
  * fix: softwareupdate under dry run (#668)
  * feat: support wildcard in ignored_containers (#666)
* Wed Apr 24 2024 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Upgrade dependencies
  * Fix boo#1223244/CVE-2024-32650 by pushing rustls to 0.21.11
* Mon Apr 15 2024 Gerald Chen <gerald_chen@foxmail.com>
- Uppate to version 14.0.1:
  * workflows(homebrew): replace Homebrew/actions/bump-formulae with Homebrew/actions/bump-packages (#656)
  * chore: fix file name typo[skip ci] (#657)
  * docs: add doc on how to do a new release (#658)
  * feat: skip breaking changes notification with env var (#659)
  * Follow up to the follow up in #616 (#660)
  * fix vscode extensions update step (#650)
  * Fix system updates for Nobara (#661)
  * chore: release v14.0.1 (#662)
- Update to version 14.0.0:
  * fix: omz remote execution if ZSH is not present (#592)
  * chore: update issue template label (#596)
  * Added Bun packages step (#599)
  * docs: fix typo in config.example.toml (#603)
  * docs: migration and breaking changes (#606)
  * revert git pushing functionalities (#615)
  * refactor: cleanup for #615 (#616)
  * Make zinit and zi use parallel updates (#614)
  * Bun packages fixes (#617)
  * chore(deps): bump all deps (#618)
  * Add option to ignore containers to pull (#613)
  * Update config.example.toml (#621)
  * feat: inform users of breaking changes on first run (#619)
  * fix: remove deprecated brew option '--ignore-pinned' (#629)
  * Skip nix upgrade-nix when Nix is installed in a nix profile (#622)
  * refactor: update pip if extern managed and global.break-system-packages is true (#634)
  * feat(pipx-update): add quiet flag for pipx upgrade-all on version 1.4.0+ (#635)
  * fix(os) consider Fedora Kinoite to be the Fedora Silverblue distribution (#638)
  * Added an Audit step for FreeBSD and DragonFly packagees. (#640)
  * chore(deps): bump h2 from 0.3.22 to 0.3.24 (#645)
  * fix: oh-my-zsh step issue #646 (#647)
  * chore: release v14.0.0 (#652)
* Thu Nov 16 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 13.0.0:
  * bump deps
  * docs: new demo video (#584)
  * fix: make logger work while loading config file (#581)
  * switch git push and pull order (#578)
  * fix: shellexpand git.pull_only_repos & git.push_only_repos (#576)
  * Add support for pushing custom git repositories (#574)
  * fix: disable dotnet greeting msg with DOTNET_NOLOGO=true (#573)
  * fix: Support yes option for opam upgrade (#570)
  * Fix builds and runs on DragonFly BSD (#569)
  * fix: --yes option for protonup (#560)
  * chore: add the check for the --yes opt in PR template (#561)
  * feat(wsl): pass verbose to topgrade-in-wsl (#556)
  * feat: add option for nix-env arguments (#555)
  * fix: remote oh-my-zsh env var export issue (#528)
  * Make error messages nicer (#551)
  * fix: fix "Nix" step to use `nix upgrade-nix` in more situations (#550)
  * feat: allow setting `misc.log_filters` in `config.toml` (#552)
  * fix: skip needrestart when using nala on debian-based distro (#548)
  * refactor: deprioritize please-sudo (#541)
  * feat: support LURE (#537)
  * feat: support Vscode packages updates (#536)
  * chore: add check for dry-run opt in PR template (#538)
  * feat: support miktex packages update (#535)
  * Prioritize sudo steps to prevent sudo timeout (#532)
  * chore: add ssh-related questions in issue template (#523)
* Sat Jul 29 2023 stigpro@outlook.fr 
- Update to version 12.0.2:
  * chore: release v12.0.2 (#518)
  * fix: WSL detection (#508)
  * fix: fix Linux and DragonFlyBSD yes option (#513)
  * feat: extra arguments for Home Manager (#507)
  * feat: better error message on wrong os-release file (#511)
  * chore: release v12.0.1 (#510)
  * chore: bump ci toolchain and MSRV (#506)
  * fix(oh-my-zsh): fix remote oh-my-zsh issue (#496)
  * CI: release to PyPI (#500)
  * feat: add assume-yes to more Linux managers (#501)
  * test: unit test for Solus (#504)
  * Fix clippy warning about non_minimal_cfg (#505)
  * Ass assume-yes to DragonflyBSD (#502)
  * steps/toolbx: Don't self-update and don't send notifications (#503)
  * chore: bump tempfile to ~3.6
  * fix(generic): add alternate binary name for spicetify (#486)
  * docs(config): document 4 missing sections in example config file (#485)
  * fix: fix wrong path in oh-my-bash (#478)
  * ci: separate code-coverage and test-config-creation (#488)
  * docs: apply corrections in config.example.toml (#492)
  * docs: add Karma commit messages to CONTRIBUTING.md (#493)
  * Update only base conda env (#495)
  * refactor(config): move sudo_command to section misc (#484)
  * v12 Cargo files update (#441)
  * test: test for config file creation and default config file parsing (#459)
  * feat: support Bob (#461)
  * chore: update bug report issue template (#474)
  * fix(pip3): prefer python when available (#471)
  * fix: Run AstroUpdate before Lazy sync (#473)
  * fix: handle no topgrade.toml but files in topgrade.d (#460)
  * refactor: unify the behavior of the steps that require sudo (#467)
  * fix: fix Mist (#466)
  * Revert "fix: fix mist" (#465)
  * fix: fix mist (#464)
  * refactor: make update fn take &ExectionContext & put update fn together (#457)
  * docs: update CONTRIBUTING.md & config.example.toml (#458)
  * fix: warn user about bad pattern paths before skipping step git (#456)
  * fix: Handle '# [include]'. Update default config (#450)
  * fix: run AM without sudo (#454)
  * docs: add config-related CONTRIBUTING doc (#452)
  * fix: Write to correct config path when none exists. (#449)
  * feat: Add arguments to pipupgrade and fix enable_pipupgrade check (#448)
  * feat: support Vanilla Linux (#447)
  * refactor: remove Anarchy and Antergos as they are discontinued (#446)
  * fix: fix panic during container update (#445)
  * feat: support deepin OS (#444)
  * refactor: remove unnecessary qualification (#443)
  * refactor: rename update fn name & some cleanup (#442)
  * Allow apt-get update to continue to apt-get upgrade with error code 100 (#440)
  * Merge code for desktop notification between MacOS and Linux (#438)
  * docs: CONTRIBUTING.md (#439)
  * Added ability to include directories as an extension of the config file (#421)
  * fix: fix .NET language issue (#437)
  * refactor: make all step functions take &ExectutionContext (#436)
  * fix: use --platform opt when pulling containers (#435)
  * fix: use env ZSH to compose oh-my-zsh install dir (#434)
  * fix: run deb-get without sudo (#430)
  * Adding local pip-review (#433)
  * Differentiate NPM and PNPM steps in name (#431)
  * feat: support maza (#427)
  * feat: support oh-my-bash (#425)
  * feat: support AppMan (#423)
  * feat(shell): add `packer.nu` (#414)
  * Make `zypper dist-upgrade` opt-in on SLE/Leap (#417)
  * feat: support stew (#422)
  * docs: update README for alternative config path (#419)
  * Add the ability to have the config file in $XDG_CONFIG_HOME/topgrade/topgrade.toml (#418)
* Fri May  5 2023 Nicolas FORMICHELLA <stigpro@outlook.fr>
- Initial packaging of v11.0.2
  * Add Scoop manifest link for Windows installation
  * run_custom_command: allow using interactive shell on unix
  * Add no-self-update config and flag
  * Display the preamble in Linux only if notify-send is installed
  * No need to run self-update in Rustup
  * Bump h2 from 0.3.16 to 0.3.17
  * Added support to 'mamba' (alternative to 'conda' with the exact same commands/interface)
  * Bump enumflags2 from 0.7.5 to 0.7.7
  * Assume Fedora Silverblue based on os-release and not on existence of rpm-ostree
  * Replace directories with home & etcetera
  * dependency update
